#!/bin/bash

# Install entire Development Tools and Web Server groups

# If we haven't read functions.sh by now, then read it
if [ "x$ZTFUNCTIONS" = "x" ]; then
  if [ -f lib/functions.sh ]; then
    . lib/functions.sh
  elif [ -f ../lib/functions.sh ]; then
    cd ..
    . lib/functions.sh
  else
    echo 'Sorry, I need to be able to source functions.sh first.'
    echo Exiting...
    exit 1
  fi
fi

shout
shout =================================================================
shout
shout Install web server
shout
shout =================================================================
shout

if [ "$OSVER" -ge "9" ]; then
  shout 'Installing httpd and mod_ssl'
  pause
  dnf -y install httpd mod_ssl
  shout Enabling httpd on next boot
  systemctl enable httpd
  shout
  shout 'And ensure you have the language packs installed'
  pause
  dnf -y install glibc-all-langpacks
elif [ "$OSVER" -eq "8" ]; then
  shout 'Installing module httpd'
  pause
  dnf -y module install httpd
  shout Enabling httpd on next boot
  systemctl enable httpd
  shout
  shout 'And ensure you have the language packs installed'
  pause
  dnf -y install glibc-all-langpacks
elif [ "$OSVER" -eq "7" ]; then
  shout 'Installing yum group "Web Server"'
  pause
  yum -y --exclude='php*' groups install "Web Server"
  shout Enabling httpd on next boot
  systemctl enable httpd
else
  shout 'Installing yum group "Web Server"'
  pause
  yum -y --exclude='php*' groupinstall "Web Server"
  shout Enabling httpd on next boot
  chkconfig httpd on
fi
pause

# Do we need this at all on CentOS/RHEL 8?
# Yes as CentOS/RHEL 8 PHP does not include sodium or imap support
#if [ "$OSVER" -ge "8" ]; then
#  shout Skipping EPEL repo on RedHat Enterprise 8 and above
#  exit 0
#fi

# Install the EPEL repo
if yum repolist all | egrep -q '^\**epel[[:space:]]'; then
  shout The EPEL extra packages repo is already installed
  if yum repolist all | egrep -q '^\**epel[[:space:]].*disabled'; then
    shout 'but it is disabled.'
    shout 'As you will have done this manually, I must now stop and ask you'
    shout 'to re-enable it in /etc/yum.repos.d/epel.repo.'
    shout 'Please ONLY enable the main epel repo itself, not the other repos'
    shout 'contained in the same file.'
    shout 'When you have done that, re-run this installer.'
    shout 'Exiting...'
    exit 1
  else
    shout and it is enabled. Good.
  fi
else
  shout Installing the EPEL extra packages repo
  pause
  if [ "$OS" = "centos" -o "$OS" = "rocky" ]; then
    yum -y install epel-release
    rpm --import /etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-"$OSVER"
  else
    yum -y install curl
    yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-"$OSVER".noarch.rpm || {
      if [ -f /etc/yum.repos.d/epel.repo ]; then
        shout
        shout 'I could not get and install the RPM that sets up the EPEL repo,'
        shout 'but you appear to probably have it installed already.'
        shout 'I will carry on...'
        pause
      else
        shout
        shout 'Eek! Could not get and install the RPM that sets up the EPEL repo.'
        shout 'Please find it on fedoraproject.org and install it, then re-run this script.'
        shout 'Exiting...'
        exit 1
      fi
    }
    rpm --import /etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-"$OSVER"
  fi
fi

exit 0

