#!/usr/bin/env bash

# Install PHP 7.2

# If we haven't read functions.sh by now, then read it
if [ "x$ZTFUNCTIONS" = "x" ]; then
  if [ -f lib/functions.sh ]; then
    . lib/functions.sh
  elif [ -f ../lib/functions.sh ]; then
    cd ..
    . lib/functions.sh
  else
    echo 'Sorry, I need to be able to source functions.sh first.'
    echo Exiting...
    exit 1
  fi
fi

shout
shout =================================================================
shout
shout 'Install PHP if not already installed, at least PHP 7.2'
shout
shout =================================================================
shout
pause

# Is PHP installed? If so, what version?
PHPVER='none'
PHPMAJOR=0
PHPPREFIX=''

# Find the php binary first. Let's hope 'which' is installed.
PHPBIN="$( which php 2>/dev/null )"
if [ "x$PHPBIN" != "x" ]; then
  # This gives us 7.2.6 or similar
  PHPVER="$( $PHPBIN -i |
             grep '^PHP *Version' |
             head -1 |
             awk '{ print $NF }' )"
  shout Found PHP version "$PHPVER"
  # This gives us php72
  PHPPREFIX="$( pkg which -p php | sed -e 's/^.* //; s/-[^-]*$//' )"
  # Reduce it to 7.2
  PHPVER="$( echo "$PHPVER" | sed -e 's/^\([^.]*\)\.\([^.]*\)\..*/\1\2/' )"
  # And 7
  PHPMAJOR="$( echo "$PHPVER" | sed -e 's/[0-9]$//' )"
  # Didn't work? Version=0 will force new installation
  if [ "x$PHPMAJOR" = "x" ]; then
    PHPMAJOR=0
    PHPVER=0
  fi
fi

# Find the most recent version of PHP we can get
# It will give us a string like 'php72' for 7.2.
PHPPREFIXLATEST="$( pkg search '^php[0-9]+-[0-9]' 2>/dev/null | cut -d- -f1 | sort -V | tail -1 )"
# This gives us '72'.
PHPVERLATEST="$( echo "$PHPPREFIXLATEST" | tr -dc '0-9' )"

# If there is no PHP installed, this bit is easy
if (( PHPVER == 0 )); then
  shout
  shout I am going to install the latest PHP I can find, which is "$PHPPREFIXLATEST".
  pause
  pkg install --yes "$PHPPREFIXLATEST"-{pdo,mysqli,ldap,intl,gd,enchant,json,imap,mbstring,openssl,sodium,sqlite3,gettext,filter,hash} mod_"$PHPPREFIXLATEST" "$PHPPREFIXLATEST"
  PHPVER="$PHPVERLATEST"
  PHPPREFIX="$PHPPREFIXLATEST"
  pause
fi

# If there is PHP before 7.2 installed, and it can be upgraded,
# replace it with the latest
if (( PHPVER > 0 && PHPVER < 72 && PHPVER < PHPVERLATEST )); then
  shout
  shout "I need to replace your PHP installation (${PHPPREFIX}) with the latest"
  shout one I can find, which is "$PHPPREFIXLATEST".
  pause
  pkg install --yes "$PHPPREFIXLATEST"-{pdo,mysqli,ldap,intl,gd,enchant,json,imap,mbstring,openssl,sodium,sqlite3,gettext,filter,hash} mod_"$PHPPREFIXLATEST" "$PHPPREFIXLATEST"
  pause
  PHPVER="$PHPVERLATEST"
  PHPPREFIX="$PHPPREFIXLATEST"
fi

shout You should now have all the PHP packages installed.
exit 0
