#!/usr/bin/env bash

# Setup firewall for Apache

# If we haven't read functions.sh by now, then read it
if [ "x$ZTFUNCTIONS" = "x" ]; then
  if [ -f lib/functions.sh ]; then
    . lib/functions.sh
  elif [ -f ../lib/functions.sh ]; then
    cd ..
    . lib/functions.sh
  else
    echo 'Sorry, I need to be able to source functions.sh first.'
    echo Exiting...
    exit 1
  fi
fi

shout
shout =================================================================
shout
shout Configure firewall to allow in http and https traffic
shout
shout =================================================================
shout
pause

shout Enabling ipfw access for ssh, http and https
sysrc firewall_enable=YES
sysrc firewall_quiet=YES
# A good template starting point
sysrc firewall_type="workstation"
# Add ssh, http, https to whatever was already there
sysrc firewall_myservices+="22/tcp 80/tcp 443/tcp"
# Allow from anywhere
sysrc firewall_allowservices="any"
sysrc firewall_logdeny=YES

shout Starting firewall
pause
service ipfw start

shout Limiting verbose logging to prevent DoS attack via logging
if grep -q '^net.inet.ip.fw.verbose_limit=' /etc/sysctl.conf; then
  # Already present so edit it
  sed -i.zendto -e 's/^\(net.inet.ip.fw.verbose_limit\)=.*$/\1=5/' /etc/sysctl.conf
else
  # Not there so append it
  echo 'net.inet.ip.fw.verbose_limit=5' >> /etc/sysctl.conf
fi
# And do it now too
sysctl net.inet.ip.fw.verbose_limit=5

shout
shout Your firewall has been configured to allow in ssh, http and https traffic
shout on ports 22/tcp, 80/tcp and 443/tcp.
shout

exit 0

