#!/usr/bin/env sh

# Install a new ZendTo installation into an otherwise-empty
# CentOS 5, 6, 7, 8
# Rocky 8
# RedHat Enterprise 5, 6, 7, 8
# Ubuntu Server 12, 14, 16
# Debian 8, 9, 10
# server.
#
# Need to install:
# 
# 1. Dev tools & web server
# 2. PHP
# 3. ClamAV
# 4. Firewall
# 5. httpd & PHP config. (needs PHP to be there)
# OBSOLETE 6. email <<=== Now configures PHPMailer at the end of 7.
# 7. ZendTo itself (including email)
# 8. SELinux
# 9. Leave them to edit preferences.php (with some notes)
#    and add a local user if necessary.
#    Must tell them how to test AD and/or LDAP.

# Firstly, do we have bash installed?
# And if we do, get ourselves running in it properly.
if [ "x$BASH" = "x" ]; then
  # We are running on sh and not bash.
  # And not bash running as sh.
  # So we must install bash before going any further
  if command -v bash >/dev/null 2>&1; then
    # It is already installed and on our $PATH
    :
  else
   printf '\033[1m'"Installing bash before we start."'\033[0m\n'
   # Can't use isyum() etc as I can't read lib/functions.sh yet
   if command -v yum >/dev/null 2>&1; then
     # RedHat / CentOS / rpm-based
     yum -y install bash
   elif command -v apt-get >/dev/null 2>&1; then
     # Ubuntu / Debian / dpkg-based
     apt-get update >/dev/null 2>&1 # Do it silently
     apt-get -y install bash
   elif command -v zypper >/dev/null 2>&1; then
     # SuSE or openSUSE
     zypper --non-interactive install bash
   elif command -v pkg >/dev/null 2>&1; then
     # FreeBSD
     # Auto-bootstrap pkg if it's not yet installed
     export ASSUME_ALWAYS_YES=yes
     # Have to do this if pkg wasn't installed, or the next line fails
     pkg update
     pkg install --yes bash
     unset ASSUME_ALWAYS_YES
   fi
   echo
 fi
fi
# If I'm not running in real bash, then re-exec myself in that
SHNAME="$( basename "$BASH" 2>/dev/null )"
if [ "x$SHNAME" != "xbash" ]; then
  # Not running in TRUE bash (running as bash), so re-run myself in bash
  exec bash $0 "$@"
fi

# Setup stuff we need later.
# This script exports everything needed by other parts.
. lib/functions.sh

export OK='\n\n\n\n\nIs it okay for me to'

#
# This asks the user if it is okay to start each part of the installation process.
# They may only want some of it done if the server is already partially setup.
#
# It will bail out immediately if any of the scripts return non-zero.
#

runIfYes "$OK install the web server" \
"$HERESUB/1-devtools.sh"    && \
runIfYes "$OK install PHP and its modules" \
"$HERESUB/2-php.sh" && \
runIfYes "$OK install and set up ClamAV (with SELinux config if necessary)" \
"$HERESUB/3-clamav.sh"      && \
runIfYes "$OK add firewall rules for http and https" \
"$HERESUB/4-firewall.sh"    && \
runIfYes "$OK create the ZendTo http and https websites in your Apache config and configure PHP" \
"$HERESUB/5-httpd-php.sh"       && \
#OBSOLETE for versions 4.21 onwards - now done at the end of stage 7
#OBSOLETE runIfYes "$OK install and set up email sending if not already done" \
#OBSOLETE "$HERESUB/6-email.sh"       && \
runIfYes "$OK install the ZendTo package itself and configure email sending" \
"$HERESUB/7-zendto.sh"      && \
runIfYes "$OK configure SELinux for ZendTo" \
"$HERESUB/8-selinux.sh"     && \
\
echo -en '\033[1m' && \
cat <<EOMESG1

=====================================================================
=====================================================================

Well, it looks like we made it. Yay!

You will need to reboot the server and view the home page once
before going any further.

** To quickly test it **
1. Reboot.
2. View this server's home page in a web browser.
3. Make sure you did not skip step 2 !
EOMESG1

if [ "x$OS" = "xubuntu" ]; then
  echo '4. sudo -i /opt/zendto/bin/adduser'
else
  echo '4. su -'
  echo '   /opt/zendto/bin/adduser'
fi

cat <<EOMESG2
   That will show you the syntax to use.
5. Use it to add a single test user.
6. Login to the website and drop off some files.

Now go and configure ZendTo itself in
/opt/zendto/config/preferences.php and
/opt/zendto/config/zendto.conf

For help configuring ZendTo for Active Directory, see
https://zend.to/activedirectory.php

EOMESG2
echo -e '\033[0m'

exit 0

